<?php
/**
 * This class is the Stock form that will be responsible for displaying and
 * editing stock entries in the Sesha application.
 *
 * $Id$
 *
 * Copyright 2004 Andrew Coleman <mercury@appisolutions.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Andrew Coleman <mercury@appisolutions.net>
 * @since   Sesha 1
 * @package Sesha
 * @version $Revision$
 */

require_once 'Horde/Form/Action.php';

class StockForm extends Horde_Form
{
    /**
     * The default constructor for the StockForm class.
     *
     * @param Util::Variables $vars  The default variables to use.
     */
    function StockForm(&$vars)
    {
        parent::Horde_Form($vars);

        // Buttons and hidden configuration
        $this->setButtons(_("Save Item"));
        $this->addHidden('', 'actionId', 'text', true);

        // Prepare the categories
        $categories = $GLOBALS['backend']->getCategories();
        foreach ($categories as $c) {
            $cat[$c['category_id']] = $c['category'];
        }
        // Get the list of selected categories
        $categoryIds = array();
        $t = $vars->get('category_id');
        if (!is_array($t)) { $t = array($t); }
        $categoryIds = array_merge($categoryIds, $t);
        
        // The stock ID should only be editable if you are adding a new item;
        // otherwise let the user know what the stock_id is, and then make a
        // read-only required hidden variable
        if ($vars->get('actionId') == SESHA_ADD_STOCK) {
            $this->addVariable(_("Stock ID"), 'stock_id', 'int', false, false);
        } else {
            $this->addVariable(_("Stock ID"), 'stock_id', 'int', false, true);
            $this->addHidden('', 'stock_id', 'int', true, true);
        }
        // Basic variables for any stock item
        $this->addVariable(_("Name"), 'stock_name', 'text', true, false);
        $categoryVar = &$this->addVariable(_("Category"), 'category_id',
            'multienum', false, false, null, array($cat));
        
        // Set the variables already stored in the Driver, if applicable
        foreach ($categoryIds as $categoryId) {
            $properties =
                $GLOBALS['backend']->getPropertiesForCategories($categoryId);
            if (!is_a($properties, 'PEAR_Error')) {
                foreach ($properties as $property) {
                    $fieldname  = 'property[' . $property['property_id'] . ']';
                    $fieldtitle = $property['property'];
                    $fielddesc  = !empty($property['unit']) ?
                                  $property['description'] . ' -- unit: ' .
                                  $property['unit'] : $property['description'];
                    $fieldtype  = $property['datatype'];
                    $this->addVariable($fieldtitle, $fieldname, $fieldtype,
                        false, false, $fielddesc);
                }
            }
        }
        $this->addVariable(_("Note"), 'note', 'longtext', false);

        // Default action
        $action = &Horde_Form_Action::factory('submit');
        $categoryVar->setAction($action);
        $categoryVar->setOption('trackchange', true);
    }
}
