<?php
/**
 * This file is the basic display of the Inventory application for Horde,
 * Sesha. It should also be able to display search results and other useful
 * things.
 *
 * $Id$
 * 
 * Copyright 2004 Andrew Coleman <mercury@appisolutions.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Andrew Coleman <mercury@appisolutions.net>
 * @version $Revision$
 * @since   Sesha 1
 * @package Sesha
 */
@define('SESHA_BASE', dirname(__FILE__));
require_once SESHA_BASE . '/lib/base.php';

// Page variables
$title = _("Current Inventory");

// Intial sorting options
$sortby = Util::getFormData('sortby');
$sortdir = Util::getFormData('sortdir');
if (!is_null($sortby)) {
    $prefs->setValue('sortby', $sortby);
}
if (!is_null($sortdir)) {
    $prefs->setValue('sortdir', $sortdir);
}

// Set the category if possible
$display_category = Util::getFormData('display_category');
$categories = &Sesha::listCategories();

// Search variables
$what = Util::getFormData('criteria');
$loc = Util::getFormData('location');
$where = null;
if (is_array($loc)) {
    $where = 0;
    foreach ($loc as $l) {
        $where += $l;
    }
}
if (!is_null($what) && !is_null($where)) {
    $title = _("Search Inventory");
    $table_header = _("Matching Inventory");
}

// Get the inventory
$inventory = &Sesha::listInventory($sortby, $sortdir,
    $display_category, $what, $where);
// Problem with the driver
if (is_a($inventory, 'PEAR_Error')) {
    $notification->push(sprintf(_("There was a problem with the driver: %s"),
        $inventory->getMessage()), 'horde.error');
// No stock
} elseif (empty($inventory)) {
    if (!is_null($what) && !is_null($where)) {
        $notification->push(_("There were no matching results found."),
            'horde.warning');
    } else {
        $notification->push(_("There are no stocked items."),
            'horde.warning');
    }
}

// Start page display
require SESHA_TEMPLATES . '/common-header.inc';
Sesha::menu();
// Normal stock situation
if (!empty($inventory)) {
    $sortby = $prefs->getValue('sortby');
    $sortdir = $prefs->getValue('sortdir');
    $sortbyurl = Util::addParameter('list.php', 'sortdir', abs(1 - $sortdir));
    if (isset($display_category)) {
        $sortbyurl = Util::addParameter($sortbyurl, 'display_category',
            $display_category);
    }
    require_once SESHA_TEMPLATES . '/list/stockheader.inc';

    $style = 'item1';
    foreach ($inventory as $stock) {
        if ($style == 'item1') { $style = 'item0'; }
        else { $style = 'item1'; }
        include SESHA_TEMPLATES . '/list/stocksummary.inc';
    }
    
    require_once SESHA_TEMPLATES . '/list/stockfooter.inc';
}
require $registry->getParam('templates', 'horde') . '/common-footer.inc';
