<?php
/**
 * This file will perform all major operations on Stock items with the standard
 * Sesha_Driver backends. This file will also prevent any non-authorized user
 * to modify the inventory (useful for displaying the inventory in a store or
 * catalog).
 *
 * $Id$
 *
 * Copyright 2003-2004 Bo Daley <bo@horde.org>
 * Copyright 2004 Andrew Coleman <mercury@appisolutions.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Bo Daley <bo@horde.org>
 * @author Andrew Coleman <mercury@appisolutions.net>
 * @since Sesha 1
 * @package Sesha
 * @version $Revision$
 */
@define('SESHA_BASE', dirname(__FILE__));
require SESHA_BASE . '/lib/base.php';

// Additional libraries
require_once SESHA_BASE . '/lib/StockForm.php';

// Basic actions & configuration
$actionId = Util::getFormData('actionId');
$stock_id = Util::getFormData('stock_id');
$active = Auth::isAdmin('sesha:admin');
global $backend;

// Determine action
switch ($actionId) {
case SESHA_ADD_STOCK:
    $vars = &Variables::getDefaultVariables();
    $vars->set('actionId', $actionId);
    $vars->set('stock_id', $stock_id);
    $renderer = &new Horde_Form_Renderer();
    $form = &Horde_Form::singleton('StockForm', &$vars);
    $form->setTitle(_("Add Stock To Inventory"));

    $valid = $form->validate($vars);
    if ($valid && $form->isSubmitted()) {
        // Add the item to the inventory
        $ret = $backend->add(array(
            'stock_id'   => $vars->get('stock_id'),
            'stock_name' => $vars->get('stock_name'),
            'note'       => $vars->get('note')));
        if (is_a($ret, 'PEAR_Error')) {
            $notification->push(sprintf(
                _("There was a problem adding the item: %s"),
                $ret->getMessage()), 'horde.error');
        } else {
            $stock_id = $ret;
            $notification->push(_("The item was added succcessfully."),
                'horde.success');
            // Add categories to the item
            $backend->updateCategoriesForStock($stock_id,
                $vars->get('category_id'));
            // Add properties to the item as well
            $backend->updatePropertiesForStock($stock_id,
                $vars->get('property'));
        }
        
        $url = Horde::selfURL();
        $url = Util::addParameter($url, 'actionId', SESHA_VIEW_STOCK);
        $url = Util::addParameter($url, 'stock_id', $stock_id);
        header('Location: ' . $url);
        exit;
    }
    break;
case SESHA_REMOVE_STOCK:
    if (!Auth::isAdmin('sesha:admin', PERMS_DELETE)) {
        $notification->push(
            _("You do not have sufficient permissions to delete."),
            'horde.error');
        header('Location: ' . Horde::applicationUrl('list.php', true));
        exit;
    }
    $ret = $backend->delete($stock_id);
    if (is_a($ret, 'PEAR_Error')) {
        $notification->push(sprintf(
            _("There was a problem with the driver while deleting: %s"),
            $ret->getMessage()), 'horde.error');
    } else {
        $notification->push(sprintf(
            _("Item number %d was successfully deleted"), $stock_id),
            'horde.success');
    }
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    break;
case SESHA_VIEW_STOCK:
    $active = false;
case SESHA_UPDATE_STOCK:
    if (!$active) {
        $form_title = _("View Inventory Item");
    }
    // Get the stock item
    $stock = $backend->fetch($stock_id);
    $categories = $backend->getCategories($stock_id);
    $properties = $backend->getPropertiesForStock($stock_id);

    $vars = &Variables::getDefaultVariables();
    $vars->set('actionId', $actionId);
    $vars->set('stock_id', $stock_id);
    $formname = $vars->get('formname');
    if (empty($formname)) {
        // Configure attributes
        if ($stock) {
            foreach ($stock as $key => $val) {
                $vars->set($key, $val);
            }
        }
        // Set up categories
        $categoryIds = array();
        foreach ($categories as $c) {
            $categoryIds[] = $c['category_id'];
        }
        $vars->set('category_id', $categoryIds);

        // Properties for categories
        $p = array();
        foreach ($properties as $property) {
            $p[$property['property_id']] = $property['txt_datavalue'];
        }
        $vars->set('property', $p);
    }

    // Set up form variables
    $renderer = &new Horde_Form_Renderer();
    $form = &Horde_Form::singleton('StockForm', &$vars);
    $form->setTitle((!isset($form_title) ? _("Edit Inventory Item") :
        $form_title));
    
    if ($form->validate($vars) && $form->isSubmitted()) {
        // Update the stock item
        $result = $backend->modify($vars->get('stock_id'), array(
            'stock_name' => Util::getFormData('stock_name'),
            'note'       => Util::getFormData('note')));
        
        // Update categories for the stock item
        $category = $vars->get('category_id');
        if (!empty($category)) {
            $backend->updateCategoriesForStock($stock_id, $category);
            $backend->clearPropertiesForStock($stock_id, $category);
        }

        // Update properties
        $property = $vars->get('property');
        if (count($property)) {
            $backend->updatePropertiesForStock($stock_id, $property);
        }

        if (!is_a($result, 'PEAR_Error')) {
            $notification->push(_("The stock item was successfully updated."),
                'horde.success');
        } else {
            $notification->push(sprintf(
                _("There was a problem updating the inventory: %s"),
                $result->getMessage()), 'horde.error');
        }

        // Redirect after update
        $url = Horde::selfURL();
        $url = Util::addParameter($url, 'actionId', SESHA_VIEW_STOCK);
        $url = Util::addParameter($url, 'stock_id', $vars->get('stock_id'));
        header('Location: ' . $url);
        exit;
    }
    break;
default:
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    break;
}

// Begin page display
require SESHA_TEMPLATES . '/common-header.inc';
Sesha::menu();
// Render form
if ($active) {
    $form->renderActive($renderer, $vars, Horde::selfURL(), 'post');
} else {
    $form->renderInactive($renderer, $vars, Horde::selfURL(), 'post');
}
require $registry->getParam('templates', 'horde') . '/common-footer.inc';
